.. _install:

Install
~~~~~~~

This section describes how to install and configure the Networking-Ansible
library, code-named networking_ansible. If you plan to use the library as an
ML2 driver in OpenStack, this section assumes that you already have a working
OpenStack environment with Neutron configured to provide VLAN tenant networking.

.. note::

   Note that installation and configuration may vary by distribution.

.. toctree::
   :maxdepth: 2

   install-obs.rst
   install-rdo.rst
   install-ubuntu.rst
   install-pip.rst
